@@ -12,7 +12,7 @@ import (
 	"k8s.io/apimachinery/pkg/api/resource"
 	metav1 "k8s.io/apimachinery/pkg/apis/meta/v1"
 
-	api "github.com/openshift/elasticsearch-operator/pkg/apis/logging/v1"
+	loggingv1 "github.com/openshift/elasticsearch-operator/pkg/apis/logging/v1"
 )
 
 var (
@@ -153,7 +153,7 @@ var _ = Describe("deployment", func() {
 					Template: v1.PodTemplateSpec{
 						Spec: v1.PodSpec{
 							Containers: []v1.Container{
-								v1.Container{},
+								{},
 							},
 						},
 					},
@@ -163,29 +163,33 @@ var _ = Describe("deployment", func() {
 		client = fake.NewFakeClient(&current.self)
 
 		elasticsearch = newElasticsearchContainer("someImage",
-			newEnvVars("mynodename", "clustername", "", map[api.ElasticsearchNodeRole]bool{}),
+			newEnvVars("mynodename", "clustername", "", map[loggingv1.ElasticsearchNodeRole]bool{}),
 			v1.ResourceRequirements{
 				Limits: v1.ResourceList{},
 			})
 
-		desired = &deploymentNode{
-			client: client,
-			self: apps.Deployment{
-				ObjectMeta: metav1.ObjectMeta{
-					Name:      current.self.Name,
-					Namespace: current.self.Namespace,
-				},
-				Spec: apps.DeploymentSpec{
-					Template: v1.PodTemplateSpec{
-						Spec: v1.PodSpec{
-							Containers: []v1.Container{
-								elasticsearch,
+		newDesired = func(elasticsearch v1.Container) *deploymentNode {
+			return &deploymentNode{
+				client: client,
+				self: apps.Deployment{
+					ObjectMeta: metav1.ObjectMeta{
+						Name:      current.self.Name,
+						Namespace: current.self.Namespace,
+					},
+					Spec: apps.DeploymentSpec{
+						Template: v1.PodTemplateSpec{
+							Spec: v1.PodSpec{
+								Containers: []v1.Container{
+									elasticsearch,
+								},
 							},
 						},
 					},
 				},
-			},
+			}
 		}
+
+		desired = newDesired(elasticsearch)
 	)
 
 	Context("isChanged()", func() {
@@ -197,5 +201,25 @@ var _ = Describe("deployment", func() {
 			Expect(desired.isChanged()).To(BeTrue())
 			Expect(desired.self.Spec.Template.Spec.Containers[0].Env).To(Equal(elasticsearch.Env))
 		})
+
+		It("should recognize container args when they change", func() {
+			elasticsearch.Args = []string{"list", "of", "args"}
+			desired = newDesired(elasticsearch)
+			Expect(desired.isChanged()).To(BeTrue())
+			Expect(desired.self.Spec.Template.Spec.Containers[0].Args).To(Equal(elasticsearch.Args))
+		})
+		It("should recognize container ports when they change", func() {
+			elasticsearch.Ports = []v1.ContainerPort{
+				{
+					Name:          "someotherport",
+					ContainerPort: 60000,
+					Protocol:      v1.ProtocolTCP,
+				},
+			}
+			desired = newDesired(elasticsearch)
+			Expect(desired.isChanged()).To(BeTrue())
+			Expect(desired.self.Spec.Template.Spec.Containers[0].Ports).To(Equal(elasticsearch.Ports))
+		})
+
 	})
 })
