@@ -190,9 +190,10 @@ func isPodReady(pod v1.Pod) bool {
 	return true
 }
 
-func (er *ElasticsearchRequest) updateNodeConditions(status *api.ElasticsearchStatus) {
+func (er *ElasticsearchRequest) updateNodeConditions(status *api.ElasticsearchStatus) error {
 	esClient := er.esClient
 	cluster := er.cluster
+
 	// Get all pods based on status.Nodes[] and check their conditions
 	// get pod with label 'node-name=node.getName()'
 	thresholdEnabled, err := esClient.GetThresholdEnabled()
@@ -205,8 +206,86 @@ func (er *ElasticsearchRequest) updateNodeConditions(status *api.ElasticsearchSt
 		er.refreshDiskWatermarkThresholds()
 	}
 
-	for nodeIndex := range status.Nodes {
-		node := &status.Nodes[nodeIndex]
+	if err := er.pruneMissingNodes(status); err != nil {
+		return err
+	}
+
+	if err := er.updatePodNodeConditions(status, thresholdEnabled); err != nil {
+		return err
+	}
+
+	return nil
+}
+
+func (er *ElasticsearchRequest) pruneMissingNodes(status *api.ElasticsearchStatus) error {
+	cluster := er.cluster
+
+	clusterNodes := nodes[nodeMapKey(er.cluster.GetName(), er.cluster.GetNamespace())]
+
+	ns := status.Nodes[:0]
+	for _, nodeStatus := range status.Nodes {
+
+		nodeName := "unknown name"
+		if nodeStatus.DeploymentName != "" {
+			nodeName = nodeStatus.DeploymentName
+		} else {
+			if nodeStatus.StatefulSetName != "" {
+				nodeName = nodeStatus.StatefulSetName
+			}
+		}
+
+		matchingLabels := map[string]string{
+			"component":    "elasticsearch",
+			"cluster-name": cluster.GetName(),
+			"node-name":    nodeName,
+		}
+
+		nodePodList, err := GetPodList(cluster.GetNamespace(), matchingLabels, er.client)
+		if err != nil {
+			return err
+		}
+
+		for _, node := range clusterNodes {
+			if nodeName != node.name() {
+				continue
+			}
+
+			// Filter all existing nodes in status.Nodes
+			if !node.isMissing() {
+				ns = append(ns, nodeStatus)
+				break
+			}
+
+			// Filter all pod status for missing node
+			if len(nodePodList.Items) == 0 {
+				for nodeRole, podStateMap := range status.Pods {
+					for podState, podNames := range podStateMap {
+						for idx, podName := range podNames {
+							if strings.HasPrefix(podName, nodeName) {
+								// Prune pod state maps for non existing pods
+								status.Pods[nodeRole][podState] = append(podNames[:idx], podNames[idx+1:]...)
+							}
+						}
+					}
+				}
+			}
+		}
+	}
+
+	// Set pruned node status to their zero value
+	// to allow garbage collection.
+	for i := len(ns); i < len(status.Nodes); i++ {
+		status.Nodes[i] = api.ElasticsearchNodeStatus{} // or the zero value of T
+	}
+	status.Nodes = ns
+
+	return nil
+}
+
+func (er *ElasticsearchRequest) updatePodNodeConditions(status *api.ElasticsearchStatus, thresholdEnabled bool) error {
+	cluster := er.cluster
+
+	for nodeIndex, node := range status.Nodes {
 
 		nodeName := "unknown name"
 		if node.DeploymentName != "" {
@@ -217,23 +296,26 @@ func (er *ElasticsearchRequest) updateNodeConditions(status *api.ElasticsearchSt
 			}
 		}
 
-		nodePodList, _ := GetPodList(
-			cluster.Namespace,
-			map[string]string{
-				"component":    "elasticsearch",
-				"cluster-name": cluster.Name,
-				"node-name":    nodeName,
-			},
-			er.client,
-		)
-		for _, nodePod := range nodePodList.Items {
+		nodeStatus := &status.Nodes[nodeIndex]
 
+		matchingLabels := map[string]string{
+			"component":    "elasticsearch",
+			"cluster-name": cluster.GetName(),
+			"node-name":    nodeName,
+		}
+
+		nodePodList, err := GetPodList(cluster.GetNamespace(), matchingLabels, er.client)
+		if err != nil {
+			return err
+		}
+
+		for _, nodePod := range nodePodList.Items {
 			isUnschedulable := false
 			for _, podCondition := range nodePod.Status.Conditions {
 				if podCondition.Type == v1.PodScheduled && podCondition.Status == v1.ConditionFalse {
 					podCondition.Type = v1.PodReasonUnschedulable
 					podCondition.Status = v1.ConditionTrue
-					updatePodUnschedulableCondition(node, podCondition)
+					updatePodUnschedulableCondition(nodeStatus, podCondition)
 					isUnschedulable = true
 				}
 			}
@@ -241,7 +323,7 @@ func (er *ElasticsearchRequest) updateNodeConditions(status *api.ElasticsearchSt
 			if isUnschedulable {
 				continue
 			}
-			updatePodUnschedulableCondition(node, v1.PodCondition{
+			updatePodUnschedulableCondition(nodeStatus, v1.PodCondition{
 				Status: v1.ConditionFalse,
 			})
 
@@ -250,14 +332,14 @@ func (er *ElasticsearchRequest) updateNodeConditions(status *api.ElasticsearchSt
 				if containerStatus.Name == "elasticsearch" {
 					if containerStatus.State.Waiting != nil {
 						updatePodNotReadyCondition(
-							node,
+							nodeStatus,
 							api.ESContainerWaiting,
 							containerStatus.State.Waiting.Reason,
 							containerStatus.State.Waiting.Message,
 						)
 					} else {
 						updatePodNotReadyCondition(
-							node,
+							nodeStatus,
 							api.ESContainerWaiting,
 							"",
 							"",
@@ -265,14 +347,14 @@ func (er *ElasticsearchRequest) updateNodeConditions(status *api.ElasticsearchSt
 					}
 					if containerStatus.State.Terminated != nil {
 						updatePodNotReadyCondition(
-							node,
+							nodeStatus,
 							api.ESContainerTerminated,
 							containerStatus.State.Terminated.Reason,
 							containerStatus.State.Terminated.Message,
 						)
 					} else {
 						updatePodNotReadyCondition(
-							node,
+							nodeStatus,
 							api.ESContainerTerminated,
 							"",
 							"",
@@ -282,14 +364,14 @@ func (er *ElasticsearchRequest) updateNodeConditions(status *api.ElasticsearchSt
 				if containerStatus.Name == "proxy" {
 					if containerStatus.State.Waiting != nil {
 						updatePodNotReadyCondition(
-							node,
+							nodeStatus,
 							api.ProxyContainerWaiting,
 							containerStatus.State.Waiting.Reason,
 							containerStatus.State.Waiting.Message,
 						)
 					} else {
 						updatePodNotReadyCondition(
-							node,
+							nodeStatus,
 							api.ProxyContainerWaiting,
 							"",
 							"",
@@ -297,14 +379,14 @@ func (er *ElasticsearchRequest) updateNodeConditions(status *api.ElasticsearchSt
 					}
 					if containerStatus.State.Terminated != nil {
 						updatePodNotReadyCondition(
-							node,
+							nodeStatus,
 							api.ProxyContainerTerminated,
 							containerStatus.State.Terminated.Reason,
 							containerStatus.State.Terminated.Message,
 						)
 					} else {
 						updatePodNotReadyCondition(
-							node,
+							nodeStatus,
 							api.ProxyContainerTerminated,
 							"",
 							"",
@@ -318,22 +400,22 @@ func (er *ElasticsearchRequest) updateNodeConditions(status *api.ElasticsearchSt
 				continue
 			}
 
-			usage, percent, err := esClient.GetNodeDiskUsage(nodeName)
+			usage, percent, err := er.esClient.GetNodeDiskUsage(nodeName)
 			if err != nil {
-				logrus.Debugf("Unable to get disk usage for %v", nodeName)
+				logrus.Infof("Unable to get disk usage: %s", err)
 				continue
 			}
 
 			if exceedsLowWatermark(usage, percent) {
 				if exceedsHighWatermark(usage, percent) {
 					updatePodNodeStorageCondition(
-						node,
+						nodeStatus,
 						"Disk Watermark High",
 						fmt.Sprintf("Disk storage usage for node is %vb (%v%%). Shards will be relocated from this node.", usage, percent),
 					)
 				} else {
 					updatePodNodeStorageCondition(
-						node,
+						nodeStatus,
 						"Disk Watermark Low",
 						fmt.Sprintf("Disk storage usage for node is %vb (%v%%). Shards will be not be allocated on this node.", usage, percent),
 					)
@@ -341,12 +423,13 @@ func (er *ElasticsearchRequest) updateNodeConditions(status *api.ElasticsearchSt
 			} else {
 				if percent > float64(0.0) {
 					// if we were able to pull the usage but it isn't above the thresholds -- clear the status message
-					updatePodNodeStorageCondition(node, "", "")
+					updatePodNodeStorageCondition(nodeStatus, "", "")
 				}
 			}
-
 		}
 	}
+
+	return nil
 }
 
 func (er *ElasticsearchRequest) refreshDiskWatermarkThresholds() {
@@ -543,6 +626,11 @@ func isPodImagePullBackOff(conditions []api.ClusterCondition) bool {
 	return condition != nil && condition.Status == v1.ConditionTrue
 }
 
+func isPodCrashLoopBackOff(conditions []api.ClusterCondition) bool {
+	condition := getESNodeConditionWithReason(conditions, api.ESContainerWaiting, "CrashLoopBackOff")
+	return condition != nil && condition.Status == v1.ConditionTrue
+}
+
 func getESNodeCondition(conditions []api.ClusterCondition, conditionType api.ClusterConditionType) (int, *api.ClusterCondition) {
 	if conditions == nil {
 		return -1, nil
